%define majver %(echo %version | cut -d. -f1-2)
%define pkgver %(echo %version | tr . -)
Name:          ogre
Epoch:         1
Version:       14.3.1
Release:       1mamba
Summary:       A scene-oriented, flexible 3D engine
Group:         Development/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.ogre3d.org/
Source:        https://github.com/OGRECave/ogre.git/v%{version}/ogre-%{version}.tar.bz2
Patch0:        ogre-1.9.20140831hg-missing-latomic.patch
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: java-openjdk11-runtime
BuildRequires: java-openjdk8-runtime
BuildRequires: libICE-devel
BuildRequires: libQt5Core
BuildRequires: libQt5Gui
BuildRequires: libSDL2-devel
BuildRequires: libSM-devel
BuildRequires: libX11-devel
BuildRequires: libXaw-devel
BuildRequires: libXext-devel
BuildRequires: libXrandr-devel
BuildRequires: libXt-devel
BuildRequires: libbullet-devel
BuildRequires: libfreetype-devel
BuildRequires: libgcc
BuildRequires: libglvnd-devel
BuildRequires: libpython310-devel
BuildRequires: libstdc++6-devel
BuildRequires: libz-devel
BuildRequires: mono-devel
BuildRequires: pugixml-devel
BuildRequires: qt5-qtbase-devel
## AUTOBUILDREQ-END
BuildRequires: cmake
BuildRequires: swig3

%description
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented, flexible 3D engine written in C++ designed to make it easier and more intuitive for developers to produce applications utilising hardware-accelerated 3D graphics.
The class library abstracts all the details of using the underlying system libraries like Direct3D and OpenGL and provides an interface based on world objects and other intuitive classes.

%package devel
Group:         Development/Libraries
Summary:       Static libraries and headers for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description devel
OGRE (Object-Oriented Graphics Rendering Engine) is a scene-oriented, flexible 3D engine written in C++ designed to make it easier and more intuitive for developers to produce applications utilising hardware-accelerated 3D graphics.
The class library abstracts all the details of using the underlying system libraries like Direct3D and OpenGL and provides an interface based on world objects and other intuitive classes.

%debug_package

%prep
%setup -q
#-D -T
#:<< __EOF
#%patch0 -p1
#-n %{name}_src_v%{ver_download}
# use cmake default
#rm CMake/Packages/FindFreetype.cmake

%build
#:<< _EOF
%cmake -d build \
    -DOGRE_RESOURCEMANAGER_STRICT=0 \
    -DOGRE_NODELESS_POSITIONING=ON \
    -DOGRE_BUILD_DEPENDENCIES=FALSE \
    -DOGRE_BUILD_PLUGIN_FREEIMAGE=TRUE \
    -DOGRE_BUILD_PLUGIN_EXRCODEC=TRUE \
	-DSWIG_EXECUTABLE=/usr/bin/swig3 \
	-DPYTHON_EXECUTABLE=%{__python310} \
	-DPYTHON_INCLUDE_DIR=%{python310_inc}
	
#	-DSWIG_DIR_PATH=/usr/share/swig/3.0.12

#_EOF

%make -j2

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall -C build

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%files
%defattr(-,root,root)
%{_bindir}/OgreMeshUpgrader
%{_bindir}/OgreXMLConverter
%{_bindir}/SampleBrowser
%{_bindir}/VRMLConverter
%{_libdir}/libOgreBites.so.*
%{_libdir}/libOgreBitesQt.so.*
#%{_libdir}/libOgreHLMS.so.*
%{_libdir}/libOgreMeshLodGenerator.so.*
%{_libdir}/libOgreOverlay.so.*
%{_libdir}/libOgreVolume.so.*
%{_libdir}/libOgreMain.so.*
%{_libdir}/libOgrePaging.so.*
%{_libdir}/libOgreProperty.so.*
%{_libdir}/libOgreRTShaderSystem.so.*
%{_libdir}/libOgreTerrain.so.*
%dir %{_libdir}/OGRE
%{_libdir}/OGRE/*
%exclude %{_libdir}/OGRE/cmake
%dir %{_datadir}/OGRE-%{majver}
%{_datadir}/OGRE-%{majver}/*
%{_datadir}/java/Ogre-%{version}.jar
%dir %{_prefix}/lib/cli/ogre-sharp-%{version}
%{_prefix}/lib/cli/ogre-sharp-%{version}/*
%dir %{_prefix}/lib/python3.10/dist-packages/Ogre
%{_prefix}/lib/python3.10/dist-packages/Ogre/*
%dir %{_datadir}/doc/OGRE
%{_datadir}/doc/OGRE/*
%doc AUTHORS LICENSE

%files devel
%defattr(-,root,root)
%dir %{_includedir}/OGRE
%{_includedir}/OGRE/*
#%{_libdir}/libOgreGLSupport.a
%{_libdir}/*.so
#%{_prefix}/lib/libOgre.so
%{_libdir}/OGRE/cmake/*.cmake
%{_libdir}/pkgconfig/*.pc


%changelog
* Sat Nov 02 2024 Automatic Build System <autodist@openmamba.org> 14.3.1-1mamba
- automatic version update by autodist

* Sun Sep 22 2024 Automatic Build System <autodist@openmamba.org> 14.3.0-1mamba
- automatic version update by autodist

* Thu Jun 06 2024 Automatic Build System <autodist@openmamba.org> 14.2.6-1mamba
- automatic version update by autodist

* Mon May 13 2024 Automatic Build System <autodist@openmamba.org> 14.2.5-1mamba
- automatic version update by autodist

* Tue Apr 23 2024 Automatic Build System <autodist@openmamba.org> 14.2.4-1mamba
- automatic version update by autodist

* Wed Mar 13 2024 Automatic Build System <autodist@openmamba.org> 14.2.2-1mamba
- automatic version update by autodist

* Thu Mar 07 2024 Automatic Build System <autodist@openmamba.org> 14.2.1-1mamba
- automatic version update by autodist

* Mon Nov 20 2023 Automatic Build System <autodist@mambasoft.it> 14.1.2-1mamba
- automatic version update by autodist

* Tue Sep 19 2023 Automatic Build System <autodist@mambasoft.it> 14.1.0-1mamba
- automatic version update by autodist

* Thu Jul 20 2023 Automatic Build System <autodist@mambasoft.it> 14.0.1-1mamba
- automatic version update by autodist

* Thu Jul 13 2023 Automatic Build System <autodist@mambasoft.it> 14.0.0-1mamba
- automatic version update by autodist

* Tue May 09 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 13.6.4-2mamba
- rebuilt with cmake options required for stuntrally and with python 3.10

* Fri Apr 14 2023 Automatic Build System <autodist@mambasoft.it> 13.6.4-1mamba
- automatic version update by autodist

* Sat Mar 11 2023 Automatic Build System <autodist@mambasoft.it> 13.6.3-1mamba
- automatic version update by autodist

* Thu Feb 09 2023 Automatic Build System <autodist@mambasoft.it> 13.6.2-1mamba
- automatic version update by autodist

* Sat Jan 28 2023 Automatic Build System <autodist@mambasoft.it> 13.6.1-1mamba
- automatic version update by autodist

* Wed Jan 18 2023 Automatic Build System <autodist@mambasoft.it> 13.6.0-1mamba
- automatic version update by autodist

* Fri Nov 25 2022 Automatic Build System <autodist@mambasoft.it> 13.5.3-1mamba
- automatic version update by autodist

* Sat Nov 19 2022 Automatic Build System <autodist@mambasoft.it> 13.5.2-1mamba
- automatic version update by autodist

* Sat Aug 20 2022 Automatic Build System <autodist@mambasoft.it> 13.4.4-1mamba
- automatic version update by autodist

* Sun Jul 17 2022 Automatic Build System <autodist@mambasoft.it> 13.4.2-1mamba
- automatic version update by autodist

* Tue Jun 28 2022 Automatic Build System <autodist@mambasoft.it> 13.4.1-1mamba
- automatic version update by autodist

* Thu Jun 09 2022 Automatic Build System <autodist@mambasoft.it> 13.4.0-1mamba
- automatic version update by autodist

* Thu Apr 07 2022 Automatic Build System <autodist@mambasoft.it> 13.3.4-1mamba
- automatic version update by autodist

* Mon Feb 21 2022 Automatic Build System <autodist@mambasoft.it> 13.3.1-1mamba
- automatic version update by autodist

* Mon Dec 13 2021 Automatic Build System <autodist@mambasoft.it> 13.2.4-1mamba
- automatic version update by autodist

* Thu Dec 09 2021 Automatic Build System <autodist@mambasoft.it> 13.2.1-1mamba
- automatic version update by autodist

* Tue Nov 30 2021 Automatic Build System <autodist@mambasoft.it> 13.2.0-1mamba
- automatic version update by autodist

* Mon Oct 18 2021 Automatic Build System <autodist@mambasoft.it> 13.1.1-1mamba
- automatic version update by autodist

* Sun Oct 17 2021 Automatic Build System <autodist@mambasoft.it> 13.1.0-1mamba
- automatic version update by autodist

* Tue Aug 17 2021 Automatic Build System <autodist@mambasoft.it> 13.0.0-1mamba
- automatic version update by autodist

* Mon Aug 02 2021 Automatic Build System <autodist@mambasoft.it> 1.12.12-2mamba
- automatic version update by autodist

* Sun Aug 01 2021 Automatic Build System <autodist@mambasoft.it> 1.12.12-1mamba
- automatic version update by autodist

* Fri Jan 04 2019 Automatic Build System <autodist@mambasoft.it> 1.11.5-1mamba
- automatic version update by autodist

* Sun Dec 09 2018 Automatic Build System <autodist@mambasoft.it> 1.11.4-1mamba
- automatic version update by autodist

* Thu Oct 11 2018 Automatic Build System <autodist@mambasoft.it> 1.11.2-1mamba
- automatic version update by autodist

* Thu Sep 13 2018 Automatic Build System <autodist@mambasoft.it> 1.11.1-1mamba
- automatic version update by autodist

* Sun Sep 09 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.10.12-1mamba
- update to 1.10.12

* Fri Feb 12 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.1-2mamba
- rebuilt with gcc 5.3.0

* Sun Aug 31 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.1-1mamba
- update to 1.8.1
- revert to stable 1.8.1 for stuntrally (bump up epoch)

* Sun Aug 31 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 1.9.20140831hg-1mamba
- update to 1.9.20140831hg
- move devel files to -devel package

* Mon Dec 02 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.9.0-2mamba
- rebuilt with boost 1.55

* Tue Nov 26 2013 Automatic Build System <autodist@mambasoft.it> 1.9.0-1mamba
- automatic version update by autodist

* Sun Jan 20 2013 openmamba WebBuild System <webbuild@openmamba.org> 1.8.1-2mamba
- fixed summary

* Tue Oct 30 2012 openmamba WebBuild System <webbuild@openmamba.org> 1.8.1-1mamba
- package created by autospec